@@ -1,8 +1,8 @@
 package Data::Difflet;
 use strict;
-use warnings;
+use warnings FATAL => 'recursion';
 use 5.008008;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 use Term::ANSIColor;
 use Data::Dumper;
 
